package net.yaoyi.gulop.member.auth.constant.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;

@Getter
@AllArgsConstructor
public enum ContractStatus {
    WAIT_SIGN(0, "等待签约"),
    SIGNING(1, "签约中"),
    SIGNED(2, "已签约"),
    EXPIRED(3, "过期"),
    REJECTED(4, "拒签"),
    INVALID(6, "作废"),
    REVOKED(7, "撤销");

    /**
     * 响应结果状态码
     */
    private final Integer code;

    /**
     * 响应结果信息
     */
    private final String message;


    /**
     * 根据 code 获取枚举值
     * @param code 状态码
     * @return 对应的枚举值，未匹配时抛出异常
     */
    public static ContractStatus fromCode(Integer code) {
        for (ContractStatus status : values()) {
            if (status.code.equals(code)) {
                return status;
            }
        }
        throw new IllegalArgumentException("无效状态码: " + code);
    }


    //对比
    public static boolean in(Integer code, ContractStatus... statuses) {
        if (code == null || statuses == null) return false;
        return Arrays.stream(statuses).anyMatch(s -> s.getCode().equals(code));
    }
}
