package net.yaoyi.gulop.member.auth.constant.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;
import net.yaoyi.gulop.member.auth.api.IErrorCode;
import net.yaoyi.gulop.member.auth.constant.CommonConstants;

/**
 * {@code ResultCodeEnum}
 * <p>
 * 响应结果枚举
 *
 * @author Hengchen.Sun
 * @version 1.0.0
 * @date 2021/10/22 16:51
 */
@Getter
@AllArgsConstructor
public enum ResultCodeEnum implements IErrorCode {

    // ~ [通用] ========================================================================================================
    SUCCESS(CommonConstants.SUCCESS, CommonConstants.SUCCESS_MSG),
    FAILURE(CommonConstants.FAIL, CommonConstants.FAIL_MSG),

    INVALID_PARAMETERS(400001, "无效的参数"),
    DUPLICATE_UNIQUE_KEY(400002, "唯一键值重复"),
    CONVERT_TO_RESULT_FAILURE(400003, "包装响应结果失败"),
    NO_SUCH_RECORD(400004, "查询记录不存在"),
    ERROR_STATUS(400005, "错误的状态"),
    CANNOT_DO_THIS(400006, "没有权限操作"),
    SYSTEM_ELEMENT(400007, "系统元素"),
    HAS_CHILDREN(400008, "包含子集"),
    SQL_ERROR(400008, "SQL有误"),
    SERVICE_EXPIRED(400009, "服务已到期"),
    REMOTE_REQUEST_ERROR(400010, "远端请求失败"),
    BABY_ON_BOARD(400011, "存在在途操作"),
    DEADLINE_EXPIRED(400012, "已过期"),
    HANDLE_MESSAGE_FAILURE(400013, "处理消息失败"),


    // ~ [租户] ========================================================================================================
    THIS_IS_PLATFORM(401001, "这是平台，不能被删除"),


    // ~ [合同] ========================================================================================================
    EXIST_AVAILABLE_CONTRACT_TEMPLATE(402001, "存在可用的合同模板"),

    // ~ [OSS] ========================================================================================================
    UPLOAD_FILE_FAILURE(403001, "上传文件失败"),
    DOWNLOAD_FILE_FAILURE(403002, "文件获取失败"),
    CREATE_BUCKET_FAILURE(403003, "创建OSS桶失败"),
    BUCKET_CAPACITY_NOT_ENOUGH(403004, "桶容量不足"),

    // ~ [用户] ========================================================================================================
    I_AM_SUPERMAN(404001, "我是SUPERMAN，不能被删除"),
    PASSWORD_INVALID(404002, "密码不正确"),

    // ~ [字典] ========================================================================================================


    // ~ [GIG] ========================================================================================================


    ;

    /**
     * 响应结果状态码
     */
    private final Integer code;

    /**
     * 响应结果信息
     */
    private final String message;
}
