package net.yaoyi.gulop.member.auth.constant.enums.state;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * {@code UmsStatus}
 * <p>
 * 会员模块状态枚举
 *
 * @author Hengchen.Sun
 * @version 1.0.0
 * @date 2022/03/20 21:06
 */
public class UmsStatus {

    /**
     * {@code TaxHelperCertStatus} 税邦云认证枚举
     *
     * @author Hengchen.Sun
     * @version 1.0.0
     * @date 2021-02-24
     * @since ver.1.0.0
     */
    @Getter
    @AllArgsConstructor
    public enum TaxHelperCertStatus {

        // 认证状态
        UN_CERT(10, "未认证"),
        ADD_MEMBER(11, "已增员"),
        CHECKED_UNBIND(12, "已认证未绑卡"),
        CHECKING_BIND(13, "认证中已绑卡"),
        CHECKING_UNBIND(14, "认证中未绑卡"),
        CERT(15, "已认证"),
        UNCHECKED_BIND(16, "未认证已绑卡");

        private final int code;

        private final String desc;

        /**
         * 根据枚举编码获取枚举对象
         *
         * @param code 枚举编码
         * @return 如果存在返回枚举，否则返回 {@code null}
         */
        public static TaxHelperCertStatus resolve(final int code) {
            for (TaxHelperCertStatus certStatus : TaxHelperCertStatus.values()) {
                if (certStatus.getCode() == code) {
                    return certStatus;
                }
            }
            return UN_CERT;

        }
    }

    /**
     * {@code CertStatus}
     * <p>
     * 易联数科签约状态枚举
     *
     * @author Hengchen.Sun
     * @author lixuesong
     * @version 1.0.0
     * @date 2022/03/09 22:21
     */
    @Getter
    @AllArgsConstructor
    public enum OladingCertStatus {

        // 签约状态
        UN_SIGNED("0", "未签约"),
        CERT("1", "已认证"),
        SIGNED("2", "已签约"),
        SIGNING("3", "签约中"),
        UN_CERT("4", "未认证");

        private final String code;

        private final String message;

        /**
         * 根据枚举编码获取枚举对象
         *
         * @param code 枚举编码
         * @return 如果存在返回枚举，否则返回 {@code null}
         */
        public static OladingCertStatus resolve(final String code) {
            for (OladingCertStatus oladingCertStatus : OladingCertStatus.values()) {
                if (oladingCertStatus.getCode().equals(code)) {
                    return oladingCertStatus;
                }
            }
            return UN_SIGNED;

        }
    }
}
