package net.yaoyi.gulop.member.auth.constant.enums.type;

import com.baomidou.mybatisplus.annotation.EnumValue;
import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * {@code CommonType}
 * <p>
 * 类型常量类
 *
 * @author Hengchen.Sun
 * @version 1.0.0
 * @date 2021/09/06 14:31:39
 */
@Getter
public final class CommonType {

    // 用户职位枚举
    @Getter
    @AllArgsConstructor
    public enum UserPosition {

        // 【高层】 ==================================
        CEO(0, "CEO", "首席执行官"),
        COO(1, "COO", "首席运营官"),
        CFO(2, "CFO", "首席财务官"),
        CTO(3, "CTO", "首席技术官"),
        CIO(4, "CIO", "首席信息官 "),
        CAO(5, "CAO", "首席艺术官 "),
        CBO(6, "CBO", "首席品牌官 "),
        CDO(7, "CDO", "首席开发官 "),
        CHO(8, "CHO", "首席信息官 "),
        CKO(9, "CKO", "首席知识官 "),
        CMO(10, "CMO", "首席市场官 "),
        CNO(11, "CNO", "首席谈判官 "),
        CPO(12, "CPO", "首席公共官 "),
        CQO(13, "CQO", "首席质量官 "),
        CSO(14, "CSO", "首席销售官 "),
        CVO(15, "CVO", "首席评估官 "),

        // [人力资源部] ===================================
        HRD(16, "HRD", "人力资源总监 "),
        HUMAN_RESOURCE_MANAGER(17, "HRM", "人力经理"),
        ASSISTANT_PERSONNEL_OFFICER(18, "APO", "人力专员"),

        // 【市场与销售】 =================================
        SALES_DIRECTOR(19, "SD", "销售总监"),
        SALES_MANAGER(20, "SM", "销售经理"),
        SALES_REPRESENTATIVE(21, "SR", "销售专员"),
        SALES_ADMINISTRATOR(22, "SA", "销售助理"),
        MARKETING_DIRECTOR(23, "MD", "市场总监"),
        MARKETING_MANAGER(24, "MM", "市场经理"),
        MARKETING_CONSULTANT(25, "MC", "市场专员"),

        // 【财务】 =================================,
        FINANCIAL_DIRECTOR(26, "FD", "财务总监"),
        FINANCIAL_MANAGER(27, "FM", "财务经理"),
        CASHIER(28, "CASHIER", "出纳"),
        ACCOUNTING(29, "ACCOUNTING", "会计"),

        // 【开发】 =================================,
        PROJECT_MANAGER(30, "PM", "项目经理"),
        DEVELOPMENTAL_ENGINEER(31, "DEV", "开发工程师"),
        OPERATIONS_ENGINEER(32, "OPS", "运维工程师"),

        // 【运营】 =================================,
        OPERATIONS_DIRECTOR(33, "OD", "运营总监"),
        OPERATIONS_MANAGER(34, "OM", "运营经理"),
        OPERATION_SPECIALIST(35, "OS", "运营专员"),

        // 【行政】 =================================,
        ADMINISTRATIVE_DIRECTOR(36, "AD", "行政总监"),
        ADMINISTRATIVE_MANAGER(37, "AM", "行政经理"),

        // 【产品】 =================================,
        PRODUCT_DIRECTOR(38, "PD", "产品总监"),
        PRODUCT_MANAGE(39, "PM", "产品经理");


        @EnumValue
        private final int type;

        /**
         * 缩写
         */
        private final String abbrev;

        private final String message;
    }

    // 用户title
    @Getter
    @AllArgsConstructor
    public enum UserTitle {

        MR(0, "先生"),
        MRS(1, "夫人"),
        MS(2, "女士"),
        MISS(3, "小姐"),
        DR(4, "博士");


        @EnumValue
        private final int code;

        private final String message;
    }

    // 性别枚举
    @Getter
    @AllArgsConstructor
    public enum Gender {

        FEMALE("FEMALE", 0, "女性"),
        MALE("MALE", 1, "男性"),
        PRIVACY("PRIVACY", 2, "保密");


        private final String type;

        @EnumValue
        private final int code;

        private final String message;
    }


    // 数据权限类型
    @Getter
    @AllArgsConstructor
    public enum DataScopeType {

        ALL(0, "全部"),
        CUSTOM(1, "自定义"),
        OWN_CHILD_LEVEL(2, "本级及子级"),
        OWN_LEVEL(3, "本级");

        /**
         * 类型
         */
        @EnumValue
        private final int type;

        /**
         * 描述
         */
        private final String message;

    }


    /**
     * {@code DictType}
     * <p>
     * 字典类型
     *
     * @author Hengchen.Sun
     * @version 1.0.0
     * @date 2021/11/10 17:17
     */
    @Getter
    @AllArgsConstructor
    public enum DictType {

        /**
         * 字典类型-系统内置（不可修改）
         */
        SYSTEM(1, "系统内置"),

        /**
         * 字典类型-业务类型
         */
        BIZ(0, "业务类");

        /**
         * 类型
         */
        private final int type;

        /**
         * 描述
         */
        private final String description;

    }


    // 打款方式
    @Getter
    @AllArgsConstructor
    public enum EndType {
        MEETING("MEETING", "BJ", "会议系统"),
        CSO("CSO", "SZ", "CSO"),
        CSO_EASY("CSO_EASY", "SZ", "CSO_EASY"),
        CSO_DEMO("CSO_DEMO", "SZ", "CSO_DEMO"),
        HCP("HCP", "BJ", "HCP"),
        HCP_DEMO("HCP_DEMO", "BJ", "HCP_DEMO"),
        JY("JY", "BJ", "JY");

        @EnumValue
        private final String type;

        private final String loc;

        private final String message;

    }

    /**
     * 登录类型
     */
    @Getter
    @AllArgsConstructor
    public enum SourceType {

        PC("PC", "PC端"),
        IOS("IOS", "苹果"),
        ANDROID("ADNROID", "安卓"),
        WECHAT_MP("WECHAT_MP", "微信小程序");

        @EnumValue
        private final String type;
        private final String description;
    }
}
