package net.yaoyi.gulop.member.auth.controller;

import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import net.yaoyi.gulop.member.auth.dto.FourElementAuthDto;
import net.yaoyi.gulop.member.auth.dto.QualificationDTO;
import net.yaoyi.gulop.member.auth.dto.ThreeElementAuthDTO;
import net.yaoyi.gulop.member.auth.entity.UmsMember;
import net.yaoyi.gulop.member.auth.service.MemberAuthService;
import net.yaoyi.gulop.member.auth.util.CommonResult;
import net.yaoyi.gulop.member.auth.util.MinioUtil;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.Map;


@Slf4j
@RestController
@RequestMapping("/api/member/auth")
@CrossOrigin(origins = "http://localhost:8080",
        allowedHeaders = "*",
        methods = {RequestMethod.GET, RequestMethod.POST})
//@Api(tags = "用户认证服务接口")
@RequiredArgsConstructor
public class MemberAuthController {

    private final MinioUtil minioUtil;

    private final MemberAuthService authService;



    //获取所有的认证信息
    @GetMapping("/get-auth_info")
    public CommonResult getAuthInfo(){
        return CommonResult.ok(authService.getAuthInfo(2L));

    }



    //个人运营商三要素认证
    @PostMapping("/three-element")
    public CommonResult threeElementAuth(@RequestBody Map<String, Object> request) {
        try{
            return authService.threeElementAuth(request,2L);
        }catch (Exception e){
            e.printStackTrace();

            return CommonResult.failed(e.getMessage());
        }
    }


    /**
     * OCR身份证识别
     * author admin@fyang.vip
     * @param file
     * @return
     */
    @PostMapping(value = "/ocr",consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public CommonResult uploadOcr(@RequestParam("file") MultipartFile file, @RequestParam("type") String type) {
        try {
            String fileUrl = minioUtil.uploadFile(file);
            return authService.ocrAuth(fileUrl,type,2L);
        } catch (Exception e) {
            return CommonResult.failed("上传失败: " + e.getMessage());
        }
    }


    //请求个人人脸活体认证
    @PostMapping("/person-face")
    public CommonResult personFace(
            @RequestBody @Valid ThreeElementAuthDTO request) {
        return authService.personFace(request,2L);
    }

    //个人银行卡四要素比对
    @PostMapping("/four-element")
    public CommonResult fourElementAuth(
            @RequestBody @Valid FourElementAuthDto request) {
        return authService.fourElementAuth(request,2L);
    }

    //保存资质证书
    @PostMapping("/check-certificate")
    public CommonResult checkCertificate(
            @RequestBody @Valid QualificationDTO qualificationDTO) {
        return authService.checkCertificate(qualificationDTO,2L);
    }

    @PostMapping("/upload")
    public CommonResult upload(@RequestParam("file") MultipartFile file) {
        try {
            log.info("开始上传");
            String fileUrl = minioUtil.uploadFile(file);
            return CommonResult.ok(fileUrl);
        } catch (Exception e) {
            return CommonResult.failed("上传失败: " + e.getMessage());
        }
    }



}

