package net.yaoyi.gulop.member.auth.controller;


import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import net.yaoyi.gulop.member.auth.service.GigConfigService;
import net.yaoyi.gulop.member.auth.util.CommonResult;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

@Slf4j
@RestController
@RequestMapping("/api/sign/contract")
@CrossOrigin(origins = "http://localhost:8080",
        allowedHeaders = "*",
        methods = {RequestMethod.GET, RequestMethod.POST})
//@Api(tags = "用户认证服务接口")
@RequiredArgsConstructor
public class SignContractController {

    private final GigConfigService gigConfigService;

    //获取签约列表
    @GetMapping("/contract-list")
    public CommonResult getList() {

        return CommonResult.ok(gigConfigService.getSignList(2L));
    }

    //签约
    @PostMapping("/sign")
    public CommonResult signContract(@RequestBody Map<String, Long> request) {
        try {
            if (request.get("config_id") == null){
                throw new RuntimeException("获取签约信息失败");
            }
            return gigConfigService.signContract(request.get("config_id"),2L );
        }catch (Exception e) {
            e.printStackTrace();
            return CommonResult.failed(e.getMessage());
        }
    }

    //查看合同信息（同步合同信息和状态）
    @PostMapping("/sign-check")
    public CommonResult signCheck(@RequestBody Map<String, String> request) {
        try {
            if (!request.containsKey("contract_id")){
                throw new RuntimeException("获取签约信息失败");
            }
            return gigConfigService.signCheck(Long.valueOf(request.get("contract_id")),2L );
        }catch (Exception e) {
            e.printStackTrace();
            return CommonResult.failed(e.getMessage());
        }
    }


    //获取报告列表
    @GetMapping("/report-list")
    public CommonResult getReportList() {

        return CommonResult.ok(gigConfigService.getReportList());
    }


    //下载报告
    @PostMapping("/report-down")
    public CommonResult getReportDown(@RequestBody Map<String, Long> request) {
        try {
            if (request.get("config_id") == null){
                throw new RuntimeException("获取报告信息失败");
            }
            return gigConfigService.getReportDown(request.get("config_id"));
        }catch (Exception e) {
            e.printStackTrace();
            return CommonResult.failed(e.getMessage());
        }
        }

}
