package net.yaoyi.gulop.member.auth.util;

import com.alibaba.fastjson.JSONObject;
import io.minio.*;
import io.minio.http.Method;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import net.yaoyi.gulop.member.auth.config.MinioConfig;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Component
@Slf4j
@RequiredArgsConstructor
public class MinioUtil {
    private final MinioClient minioClient;
    private final MinioConfig config;


    /**
     * 上传文件到MinIO
     * @param file 要上传的文件
     * @return 文件访问URL
     */
    public String uploadFile(MultipartFile file) {
        try {
            // 确保存储桶存在
            boolean found = minioClient.bucketExists(
                    BucketExistsArgs.builder()
                            .bucket(config.getBucketName())
                            .build());

            if (!found) {
                minioClient.makeBucket(
                        MakeBucketArgs.builder()
                                .bucket(config.getBucketName())
                                .build());
            }

            // 生成唯一文件名
            String fileName = generateFileName(file.getOriginalFilename());

            // 上传文件
            minioClient.putObject(
                    PutObjectArgs.builder()
                            .bucket(config.getBucketName())
                            .object(fileName)
                            .stream(file.getInputStream(), file.getSize(), -1)
                            .contentType(file.getContentType())
                            .build());
            log.info("minioClient {}",minioClient);

            // 获取访问URL
            String files = minioClient.getPresignedObjectUrl(
                    GetPresignedObjectUrlArgs.builder()
                            .method(Method.GET)
                            .bucket(config.getBucketName())
                            .object(fileName)
                            .expiry(7, TimeUnit.DAYS)
                            .build());

            return files;
        } catch (Exception e) {
            log.error("文件上传失败: {}", e.getMessage());
            throw new RuntimeException("文件上传失败", e);
        }
    }

    private String generateFileName(String originalName) {
        return UUID.randomUUID().toString().replace("-", "")
                + "-"
                + originalName.replace(" ", "_");
    }
}
